The `test` directory contains these notebooks:

`assignment.ipynb` contains a title "Notebook Title", and prompts and empty cells for "Question 1",
"Question 2", and "A Quick Poll".

`student-1.ipynb` through `student-3.ipynb` contain copies of the three prompts, with these answers:

| Notebook          | Question 1       | Question 2     | A Quick Poll   |
|-------------------|------------------|----------------|----------------|
| `student-1.ipynb` | filled-in cell   | filled-in cell | filled-in cell |
| `student-2.ipynb` | two answer cells | empty cell     | filled-in cell |
| `student-3.ipynb` | filled-in cell   | filled-in cell | empty cell     |
